#ifndef __LOG_MESSAGE_H__
#define __LOG_MESSAGE_H__

#include <string>
#include "FdsfeApi.h"

namespace FactSet {
namespace Datafeed {

struct LogMessageImpl;
class FDSFE_API LogMessage {
  public:
    enum LogLevel {
        LOG_ALL   = 0,
        LOG_DEBUG = 1,
        LOG_INFO  = 2,
        LOG_WARN  = 3,
        LOG_ERROR = 4,
        LOG_PANIC = 5,
        LOG_NONE  = 6
    };

    /*! @brief Constructor
     *
     * Constructs a new empty log message
     */
    LogMessage();

    LogMessage(const LogMessage& other);

    LogMessage& operator=(const LogMessage& other);

    /*! @brief Destructor
     */
    ~LogMessage();

    /*! @brief Gets the message text to log.
     */
    std::string get_text() const;

    /*! @brief Gets the time that this message was logged as seconds past unix
     *  epoch.
     */
    time_t get_time() const;

    /*! @brief Gets the number of microseconds past the last second that this
     *  message was logged.
     */
    unsigned int get_microseconds() const;

    /*! @brief Gets the log level of this message.
     */
    LogLevel get_level() const;

    /*! @brief Gets the name of the file from which this message originated.
     */
    std::string get_filename() const;

    /*! @brief Gets the line number from which this message originated.
     */
    int get_line_number() const;

    /*! @brief Gets the id of the thread from which this message originated.
     */
    uint64_t get_thread_id() const;

  private:
    friend struct LogMessageImpl;
    LogMessageImpl* m_impl;
};
}  // namespace Datafeed
}  // namespace FactSet
#endif
