#ifndef __MD_LIB_EPOCHNS_H__
#define __MD_LIB_EPOCHNS_H__

#include <MD/MD_sys_types.h>
#include <MD/private/prefix.h>

namespace MD {
 /*
 * MD_EpochNS
 * Stores time since epoch in nano seconds to the member epoch_ns
 * Provides member functions to set/get the value in different formats
 *
 * NOTE: we cant add any contructor here as it make the class non trivial. This would exclude it from the MD_Variant's union.
 * If we ever move to boost variant or similar then we can make this class more complete.
 *
 */
  class MD_LIB_API MD_EpochNS
  {
  public:

    void set_s(const uint64_t seconds)   {epoch_ns = seconds*SECONDS;}
    void set_ms(const uint64_t mseconds) {epoch_ns = mseconds*MSECONDS;}
    void set_us(const uint64_t useconds) {epoch_ns = useconds*USECONDS;}
    void set(const uint64_t nanoseconds) {epoch_ns = nanoseconds;}
    
    uint64_t get_s()  const {return epoch_ns/SECONDS;}
    uint64_t get_ms() const {return epoch_ns/MSECONDS;}
    uint64_t get_us() const {return epoch_ns/USECONDS;}
    uint64_t get()    const {return epoch_ns;}

    bool operator<  (const MD_EpochNS& rhs) const { return this->epoch_ns < rhs.epoch_ns; }
    bool operator<= (const MD_EpochNS& rhs) const { return this->epoch_ns <= rhs.epoch_ns; }
    bool operator>  (const MD_EpochNS& rhs) const { return this->epoch_ns > rhs.epoch_ns; }
    bool operator>= (const MD_EpochNS& rhs) const { return this->epoch_ns >= rhs.epoch_ns; }
    bool operator== (const MD_EpochNS& rhs) const { return this->epoch_ns == rhs.epoch_ns; }
    bool operator!= (const MD_EpochNS& rhs) const { return this->epoch_ns != rhs.epoch_ns; }
  
  private:
    enum MultiplyByForNano
    {
      SECONDS   = 1000000000,
      MSECONDS  = 1000000,
      USECONDS  = 1000
    };
    uint64_t epoch_ns;

  };

}

#endif
