/* Check not using more than one logger lib */
#ifdef MD_LOGGER_BOOST
  #ifdef MD_LOGGER_FIRE
    #error Error: Do not link against both fire and boost MD_Logger libs
  #endif
  #ifdef FIRE_API
    #error Error: Do not link against boost logger when using fire base library
  #endif
#endif

#ifndef __MD_LIB_LOGGER_H__
#define __MD_LIB_LOGGER_H__
  /* Dont log anything on window for MD */
  #ifdef _WIN32
    #define MD_DEB_TRACE -1
    #define md_log_raw(input) do { /* nothing */ } while(0);
    #define md_log_info(input) do { /* nothing */ } while(0);
    #define md_log_warn(input) do { /* nothing */ } while(0);
    #define md_log_error(input) do { /* nothing */ } while(0);
    #define md_log_panic(input) do { /* nothing */ } while(0);
    #define md_log_debug(input) do { /* nothing */ } while(0);
    #define md_log_trace(input) do { /* nothing */ } while(0);
    #define md_log_debug_cat(c,input) do { /* nothing */ } while(0);
    #define md_log_assert_return(exp,rtn) do { /* nothing */ } while(0);
    #define md_log_warn_line_limited(limit,input) do { /* nothing */ } while(0);
  #else
  /* On linux redefine to the standard log functions */
    #if defined(MD_LOGGER_FIRE) || defined(MD_LOGGER_BOOST)
      #define MD_DEB_TRACE FIRE_NAMESPACE::DEB_TRACE
      #define md_log_raw(input) do { log_raw(input); } while(0);
      #define md_log_info(input) do { log_info(input); } while(0);
      #define md_log_warn(input) do { log_warn(input); } while(0);
      #define md_log_error(input) do { log_error(input); } while(0);
      #define md_log_panic(input) do { log_panic(input); } while(0);
      #define md_log_debug(input) do { log_debug(input); } while(0);
      #define md_log_trace(input) do { log_trace(input); } while(0);
      #define md_log_debug_cat(c,input) do { log_debug_cat(c,input); } while(0);
      #define md_log_assert_return(exp,rtn) do { log_assert_return(exp,rtn); } while(0);
      #define md_log_warn_line_limited(limit,input) do { log_warn_line_limited(limit,input); } while(0);
    #endif

  /* Then select logger header based on a Define set in the library at compile time */
    #ifdef MD_LOGGER_FIRE
      #pragma message( "Using fire logger" )
      #include <fire/Logger.h>
    #elif MD_LOGGER_BOOST
      #pragma message( "Using boost logger" )
      #include "blog.h"
    #else
      #pragma message( "No logger selected, using default (std)" )
      #include <MD/MD_DefaultLogger.h>
    #endif

  #endif

#endif // __MD_LIB_LOGGER_H__
